# plain-esbuild changelog

## [0.5.1](https://github.com/dropseed/plain/releases/plain-esbuild@0.5.1) (2025-06-24)

### What's changed

- Added this CHANGELOG file to the package so future releases include detailed notes ([82710c3](https://github.com/dropseed/plain/commit/82710c3c8300))

### Upgrade instructions

- No changes required
